-----------------------------------------------------------------------------------------------
-- Client Lua Script for RepairCostSummary
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "GameLib"
 
-----------------------------------------------------------------------------------------------
-- RepairCostSummary Module Definition
-----------------------------------------------------------------------------------------------
local RepairCostSummary = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function RepairCostSummary:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	self.IsVendorOpen = false
	
    return o
end

function RepairCostSummary:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- RepairCostSummary OnLoad
-----------------------------------------------------------------------------------------------
function RepairCostSummary:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("RepairCostSummary.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- RepairCostSummary OnDocLoaded
-----------------------------------------------------------------------------------------------
function RepairCostSummary:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "RepairCostSummaryForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
		
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("rcs", "OnRepairCostSummaryOn", self)


		-- Do additional Addon initialization here
		Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
		Apollo.RegisterEventHandler("RepairEverything", "OnRepairEverything", self)
		Apollo.RegisterEventHandler("ItemDurabilityUpdate", "UpdateInterfaceMenuAlerts", self)
		Apollo.RegisterEventHandler("CloseVendorWindow", "VendorCheck", self)
		Apollo.RegisterEventHandler("InvokeVendorWindow", "VendorCheck", self)
			end
end


function RepairCostSummary:OnInterfaceMenuListHasLoaded()
		Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "Repair Cost", {"RepairEverything", "", "IconSprites:Icon_Windows32_UI_CRB_InterfaceMenu_Credd"})
		self:UpdateInterfaceMenuAlerts()
end

function RepairCostSummary:VendorCheck()
		self.IsVendorOpen = not self.IsVendorOpen
end


function RepairCostSummary:OnRepairEverything()
		if not self.IsVendorOpen then return 
		end
		RepairAllItemsVendor()	
		if GameLib.GetRepairAllCost() > 0 then
			Sound.Play(Sound.PlayUIVendorRepair)
		end
end

function RepairCostSummary:UpdateInterfaceMenuAlerts()
local RepairCost = GameLib.GetRepairAllCost()
		if RepairCost > 10000 then
		Event_FireGenericEvent("InterfaceMenuList_AlertAddOn", "Repair Cost", {true, "\n"..RepairCost, math.floor(RepairCost/10000+0.5)})
		else
		Event_FireGenericEvent("InterfaceMenuList_AlertAddOn", "Repair Cost", {false, "\n"..RepairCost, 0})
		end
end




-----------------------------------------------------------------------------------------------
-- RepairCostSummary Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/rcs"
function RepairCostSummary:OnRepairCostSummaryOn()
	self.wndMain:Invoke() -- show the window
end


-----------------------------------------------------------------------------------------------
-- RepairCostSummaryForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function RepairCostSummary:OnOK()
	self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function RepairCostSummary:OnCancel()
	self.wndMain:Close() -- hide the window
end


-----------------------------------------------------------------------------------------------
-- RepairCostSummary Instance
-----------------------------------------------------------------------------------------------
local RepairCostSummaryInst = RepairCostSummary:new()
RepairCostSummaryInst:Init()
